IPAM Migration Guide - Nautobot Documentation

Skip to content

# Nautobot 2.0 IPAM Migration Guide

## Goal

This document aims to answer the question "What do I need to do to my data (or what changes with my data) when migrating to 2.0, specifically IPAM?"

Each change is covered in detail to describe the changes, their impact, and the underlying reasons why the changes were made.

Please see the individual sections for more details.

## Sections

- What's Changed
- Before you Upgrade
- After you Upgrade
- For Developers